@@ -431,6 +431,7 @@ class FlatpakUpdate():
             iref_version = ""
             old_commit = ""
 
+        appstream_version = ""
         # new version
         if pkginfo:
             appstream_version = installer.get_version(pkginfo)
@@ -450,15 +451,14 @@ class FlatpakUpdate():
 
         if pkginfo:
             self.name = installer.get_display_name(pkginfo)
-        elif installed_ref:
+        elif installed_ref and self.flatpak_type != "runtime":
             self.name = installed_ref.get_appdata_name()
         else:
             self.name = ref.get_name()
 
         if pkginfo:
             self.summary = installer.get_summary(pkginfo)
-            description = installer.get_description(pkginfo)
-            self.description = re.sub(r'\n+', '\n\n', description).rstrip()
+            self.description = installer.get_description(pkginfo)
         elif installed_ref:
             self.summary = installed_ref.get_appdata_summary()
             self.description = ""
